@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_fused.c                                                           *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2021 Case Van Horsen                                   *
+ * Copyright 2008 - 2025 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -187,14 +187,14 @@ GMPy_ComplexWithType_FMA(PyObject *x, int xtype, PyObject *y, int ytype, PyObjec
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fma,
-"context.fma(x, y, z) -> number\n\n"
+"fma($self, x, y, z, /)\n--\n\n"
 "Return correctly rounded result of (x * y) + z.");
 
 PyDoc_STRVAR(GMPy_doc_function_fma,
-"fma(x, y, z) -> number\n\n"
+"fma($module, x, y, z, /)\n--\n\n"
 "Return correctly rounded result of (x * y) + z.");
 
-GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMA, fma);
+GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMA, fma)
 
 static PyObject *
 _GMPy_MPZ_FMS(PyObject *x, PyObject *y, PyObject *z, CTXT_Object *context)
@@ -362,14 +362,14 @@ GMPy_ComplexWithType_FMS(PyObject *x, int xtype, PyObject *y, int ytype, PyObjec
     return result;
 }
 PyDoc_STRVAR(GMPy_doc_context_fms,
-"context.fms(x, y, z) -> number\n\n"
+"fms($self, x, y, z, /)\n--\n\n"
 "Return correctly rounded result of (x * y) - z.");
 
 PyDoc_STRVAR(GMPy_doc_function_fms,
-"fms(x, y, z) -> number\n\n"
+"fms($module, x, y, z, /)\n--\n\n"
 "Return correctly rounded result of (x * y) - z.");
 
-GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMS, fms);
+GMPY_MPFR_MPC_TRIOP_TEMPLATEWT(FMS, fms)
 
 /* Add support for new fmma and fmms functions from MPFR 4. */\
 
@@ -521,14 +521,14 @@ GMPy_RealWithType_FMMA(PyObject *x, int xtype, PyObject *y, int ytype, PyObject
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fmma,
-"context.fmma(x, y, z, t) -> number\n\n"
+"fmma($self, x, y, z, t, /)\n--\n\n"
 "Return correctly rounded result of (x * y) + (z * t).");
 
 PyDoc_STRVAR(GMPy_doc_function_fmma,
-"fmma(x, y, z, t) -> number\n\n"
+"fmma($module, x, y, z, t, /)\n--\n\n"
 "Return correctly rounded result of (x * y) + (z + t).");
 
-GMPY_MPFR_QUADOP_TEMPLATEWT(FMMA, fmma);
+GMPY_MPFR_QUADOP_TEMPLATEWT(FMMA, fmma)
 
 static PyObject *
 _GMPy_MPZ_FMMS(PyObject *x, PyObject *y, PyObject *z, PyObject *t, CTXT_Object *context)
@@ -676,15 +676,13 @@ GMPy_RealWithType_FMMS(PyObject *x, int xtype, PyObject *y, int ytype, PyObject
 }
 
 PyDoc_STRVAR(GMPy_doc_context_fmms,
-"context.fmms(x, y, z, t) -> number\n\n"
+"fmms($self, x, y, z, t, /)\n--\n\n"
 "Return correctly rounded result of (x * y) - (z * t).");
 
 PyDoc_STRVAR(GMPy_doc_function_fmms,
-"fmms(x, y, z, t) -> number\n\n"
+"fmms($module, x, y, z, t, /)\n--\n\n"
 "Return correctly rounded result of (x * y) - (z + t).");
 
-GMPY_MPFR_QUADOP_TEMPLATEWT(FMMS, fmms);
+GMPY_MPFR_QUADOP_TEMPLATEWT(FMMS, fmms)
 
 #endif
-
-
