@@ -1,12 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * gmpy2_truediv.c                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- * Python interface to the GMP or MPIR, MPFR, and MPC multiple precision   *
+ * Python interface to the GMP, MPFR, and MPC multiple precision           *
  * libraries.                                                              *
  *                                                                         *
  * Copyright 2000 - 2009 Alex Martelli                                     *
  *                                                                         *
- * Copyright 2008 - 2021 Case Van Horsen                                   *
+ * Copyright 2008 - 2025 Case Van Horsen                                   *
  *                                                                         *
  * This file is part of GMPY2.                                             *
  *                                                                         *
@@ -24,6 +24,8 @@
  * License along with GMPY2; if not, see <http://www.gnu.org/licenses/>    *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+#include "fr_div.c"
+
 /* This file implements the / operator, gmpy2.div() and context.div().
  *
  * Public API
@@ -62,7 +64,7 @@ GMPy_Integer_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
             return NULL;
             /* LCOV_EXCL_STOP */
         }
-          
+
         if (mpz_sgn(tempy->z) == 0) {
             ZERO_ERROR("division or modulo by zero");
             Py_XDECREF((PyObject*)tempx);
@@ -81,16 +83,18 @@ GMPy_Integer_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         result->rc = mpfr_set_q(result->f, tempq, GET_MPFR_ROUND(context));
 
         mpq_clear(tempq);
-        
+
         Py_DECREF((PyObject*)tempx);
         Py_DECREF((PyObject*)tempy);
         _GMPy_MPFR_Cleanup(&result, context);
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("div() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 static PyObject *
 GMPy_Rational_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
@@ -144,9 +148,11 @@ GMPy_Rational_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("div() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 /* Attempt true division of two numbers and return an mpfr. The code path is
@@ -196,9 +202,11 @@ GMPy_Real_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("div() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 static PyObject *
@@ -232,9 +240,76 @@ GMPy_Complex_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_REAL(ytype)) {
+        MPC_Object *tempx = NULL;
+        MPFR_Object *tempy = NULL;
+
+        if (mpfr_zero_p(MPFR(y))) {
+            context->ctx.divzero = 1;
+            if (context->ctx.traps & TRAP_DIVZERO) {
+                GMPY_DIVZERO("'mpc' division by zero");
+                Py_DECREF((PyObject*)result);
+                return NULL;
+            }
+        }
+
+        if (!(tempx = GMPy_MPC_From_ComplexWithType(x, xtype, 1, 1, context)) ||
+            !(tempy = GMPy_MPFR_From_RealWithType(y, ytype, 1, context))) {
+            /* LCOV_EXCL_START */
+            Py_XDECREF((PyObject*)tempx);
+            Py_XDECREF((PyObject*)tempy);
+            Py_DECREF((PyObject*)result);
+            return NULL;
+            /* LCOV_EXCL_STOP */
+        }
+        result->rc = mpc_div_fr(result->c, tempx->c, MPFR(tempy), GET_MPC_ROUND(context));
+        Py_DECREF((PyObject*)tempx);
+        Py_DECREF((PyObject*)tempy);
+        _GMPy_MPC_Cleanup(&result, context);
+        return (PyObject*)result;
+    }
+
+    if (IS_TYPE_COMPLEX(ytype) && IS_TYPE_REAL(xtype)) {
+        MPC_Object *tempy = NULL;
+        MPFR_Object *tempx = NULL;
+
+        if (MPC_IS_ZERO_P(y)) {
+            context->ctx.divzero = 1;
+            if (context->ctx.traps & TRAP_DIVZERO) {
+                GMPY_DIVZERO("'mpc' division by zero");
+                Py_DECREF((PyObject*)result);
+                return NULL;
+            }
+        }
+
+        if (!(tempy = GMPy_MPC_From_ComplexWithType(y, ytype, 1, 1, context)) ||
+            !(tempx = GMPy_MPFR_From_RealWithType(x, xtype, 1, context))) {
+            /* LCOV_EXCL_START */
+            Py_XDECREF((PyObject*)tempx);
+            Py_XDECREF((PyObject*)tempy);
+            Py_DECREF((PyObject*)result);
+            return NULL;
+            /* LCOV_EXCL_STOP */
+        }
+        result->rc = mpc_fr_div(result->c, MPFR(tempx), tempy->c, GET_MPC_ROUND(context));
+        Py_DECREF((PyObject*)tempx);
+        Py_DECREF((PyObject*)tempy);
+        _GMPy_MPC_Cleanup(&result, context);
+        return (PyObject*)result;
+    }
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype)) {
         MPC_Object *tempx = NULL, *tempy = NULL;
 
+        if (MPC_IS_ZERO_P(y)) {
+            context->ctx.divzero = 1;
+            if (context->ctx.traps & TRAP_DIVZERO) {
+                GMPY_DIVZERO("'mpc' division by zero");
+                Py_DECREF((PyObject*)result);
+                return NULL;
+            }
+        }
+
         if (!(tempx = GMPy_MPC_From_ComplexWithType(x, xtype, 1, 1, context)) ||
             !(tempy = GMPy_MPC_From_ComplexWithType(y, ytype, 1, 1, context))) {
             /* LCOV_EXCL_START */
@@ -252,9 +327,11 @@ GMPy_Complex_TrueDivWithType(PyObject *x, int xtype, PyObject *y, int ytype,
         return (PyObject*)result;
     }
 
+    /* LCOV_EXCL_START */
     Py_DECREF((PyObject*)result);
     TYPE_ERROR("div() argument type not supported");
     return NULL;
+    /* LCOV_EXCL_STOP */
 }
 
 /* Implement all the slot methods here. */
@@ -264,7 +341,7 @@ GMPy_Number_TrueDiv_Slot(PyObject *x, PyObject *y)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
         return GMPy_Integer_TrueDivWithType(x, xtype, y, ytype, NULL);
 
@@ -273,39 +350,15 @@ GMPy_Number_TrueDiv_Slot(PyObject *x, PyObject *y)
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
         return GMPy_Real_TrueDivWithType(x, xtype, y, ytype, NULL);
-        
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
         return GMPy_Complex_TrueDivWithType(x, xtype, y, ytype, NULL);
 
     Py_RETURN_NOTIMPLEMENTED;
 }
 
-#ifdef PY2
-static PyObject *
-GMPy_Number_Div2_Slot(PyObject *x, PyObject *y)
-{
-    int xtype = GMPy_ObjectType(x);
-    int ytype = GMPy_ObjectType(y);
-    
-    if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
-        return GMPy_Integer_FloorDivWithType(x, xtype, y, ytype, NULL);
-
-    if (IS_TYPE_RATIONAL(xtype) && IS_TYPE_RATIONAL(ytype))
-        return GMPy_Rational_TrueDivWithType(x, xtype, y, ytype, NULL);
-
-    if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
-        return GMPy_Real_TrueDivWithType(x, xtype, y, ytype, NULL);
-        
-    if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
-        return GMPy_Complex_TrueDivWithType(x, xtype, y, ytype, NULL);
-
-    Py_RETURN_NOTIMPLEMENTED;
-}
-#endif
-
-
 PyDoc_STRVAR(GMPy_doc_truediv,
-"div(x, y) -> number\n\n"
+"div($module, x, y, /)\n--\n\n"
 "Return x / y; uses true division.");
 
 static PyObject *
@@ -313,25 +366,25 @@ GMPy_Number_TrueDiv(PyObject *x, PyObject *y, CTXT_Object *context)
 {
     int xtype = GMPy_ObjectType(x);
     int ytype = GMPy_ObjectType(y);
-    
+
     if (IS_TYPE_INTEGER(xtype) && IS_TYPE_INTEGER(ytype))
-        return GMPy_Integer_TrueDivWithType(x, xtype, y, ytype, NULL);
+        return GMPy_Integer_TrueDivWithType(x, xtype, y, ytype, context);
 
     if (IS_TYPE_RATIONAL(xtype) && IS_TYPE_RATIONAL(ytype))
-        return GMPy_Rational_TrueDivWithType(x, xtype, y, ytype, NULL);
+        return GMPy_Rational_TrueDivWithType(x, xtype, y, ytype, context);
 
     if (IS_TYPE_REAL(xtype) && IS_TYPE_REAL(ytype))
-        return GMPy_Real_TrueDivWithType(x, xtype, y, ytype, NULL);
-        
+        return GMPy_Real_TrueDivWithType(x, xtype, y, ytype, context);
+
     if (IS_TYPE_COMPLEX(xtype) && IS_TYPE_COMPLEX(ytype))
-        return GMPy_Complex_TrueDivWithType(x, xtype, y, ytype, NULL);
+        return GMPy_Complex_TrueDivWithType(x, xtype, y, ytype, context);
 
     TYPE_ERROR("div() argument type not supported");
     return NULL;
 }
 
 PyDoc_STRVAR(GMPy_doc_context_truediv,
-"context.div(x, y) -> number\n\n"
+"div($self, x, y, /)\n--\n\n"
 "Return x / y; uses true division.");
 
 static PyObject *
@@ -355,5 +408,3 @@ GMPy_Context_TrueDiv(PyObject *self, PyObject *args)
                                PyTuple_GET_ITEM(args, 1),
                                context);
 }
-
-
